@@ -10,6 +10,7 @@
 #include <unordered_map>
 
 #include <QDeadlineTimer>
+#include <QElapsedTimer>
 #include <QQmlComponent>
 #include <QTimer>
 
@@ -347,11 +348,7 @@ void ToolBarLayout::componentComplete()
 void ToolBarLayout::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
 {
     if (newGeometry != oldGeometry) {
-        if (newGeometry.size() != QSizeF{implicitWidth(), implicitHeight()}) {
-            relayout();
-        } else {
-            polish();
-        }
+        relayout();
     }
     QQuickItem::geometryChange(newGeometry, oldGeometry);
 }
@@ -369,7 +366,7 @@ void ToolBarLayout::updatePolish()
     d->performLayout();
 }
 
-/**
+/*
  * Calculate the implicit size for this layout.
  *
  * This is a separate step from performing the actual layout, because of a nasty
@@ -444,6 +441,8 @@ void ToolBarLayoutPrivate::calculateImplicitSize()
 
     visibleActionsWidth = 0.0;
 
+    q->setImplicitWidth(maxWidth);
+
     if (maxWidth > q->width() - (hiddenActions.isEmpty() ? 0.0 : moreButtonInstance->width() + spacing)) {
         // We have more items than fit into the view, so start hiding some.
 
@@ -476,7 +475,8 @@ void ToolBarLayoutPrivate::calculateImplicitSize()
         maxHeight = std::max(maxHeight, moreButtonInstance->implicitHeight());
     };
 
-    q->setImplicitSize(maxWidth, maxHeight);
+    q->setImplicitHeight(maxHeight);
+
     Q_EMIT q->hiddenActionsChanged();
 
     implicitSizeValid = true;
